==> haskell-tasty-rerun-1.1.20-19-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-tasty-rerun.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 tasty-rerun
version:              1.1.20
visibility:           public
id:                   tasty-rerun-1.1.20-6FKp5TjjaNK8ce1wvkI9NU
key:                  tasty-rerun-1.1.20-6FKp5TjjaNK8ce1wvkI9NU
license:              BSD-3-Clause
copyright:
    Oliver Charles (c) 2014,
    Andrew Lelechenko (c) 2019

maintainer:           ollie@ocharles.org.uk
author:               Oliver Charles
homepage:             http://github.com/ocharles/tasty-rerun
synopsis:             Rerun only tests which failed in a previous test run
description:
    This ingredient
    for the <https://hackage.haskell.org/package/tasty tasty> testing framework
    allows filtering a test tree depending
    on the outcome of the previous run.
    This may be useful in many scenarios,
    especially when a test suite grows large.

category:             Testing
abi:                  be94eed4748702a025fac6028f863e45
exposed:              True
exposed-modules:      Test.Tasty.Ingredients.Rerun
import-dirs:          /usr/lib/ghc-9.4.8/site-local/tasty-rerun-1.1.20
library-dirs:         /usr/lib/ghc-9.4.8/site-local/tasty-rerun-1.1.20
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/tasty-rerun-1.1.20
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-tasty-rerun
hs-libraries:         HStasty-rerun-1.1.20-6FKp5TjjaNK8ce1wvkI9NU
depends:
    base-4.17.2.1 containers-0.6.7 filepath-1.4.2.2 mtl-2.2.2
    optparse-applicative-0.18.1.0-CZp2uWBrZhVKrqP7dbntdc
    split-0.2.5-Dujwwofvw7aEFmjRmWhj9Q stm-2.5.1.0
    tagged-0.8.9-KMS3sfDasKWItFZcxfaN6C
    tasty-1.5-9b9FHG8OBttDZ68785yCzt transformers-0.5.6.2

haddock-interfaces:   /usr/share/doc/haskell-tasty-rerun/html/tasty-rerun.haddock
haddock-html:         /usr/share/doc/haskell-tasty-rerun/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-tasty-rerun-1.1.20-20-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-tasty-rerun.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 tasty-rerun
version:              1.1.20
visibility:           public
id:                   tasty-rerun-1.1.20-6YydCfWwoW7Ar9wECloK69
key:                  tasty-rerun-1.1.20-6YydCfWwoW7Ar9wECloK69
license:              BSD-3-Clause
copyright:
    Oliver Charles (c) 2014,
    Andrew Lelechenko (c) 2019

maintainer:           ollie@ocharles.org.uk
author:               Oliver Charles
homepage:             http://github.com/ocharles/tasty-rerun
synopsis:             Rerun only tests which failed in a previous test run
description:
    This ingredient
    for the <https://hackage.haskell.org/package/tasty tasty> testing framework
    allows filtering a test tree depending
    on the outcome of the previous run.
    This may be useful in many scenarios,
    especially when a test suite grows large.

category:             Testing
abi:                  be30f72df6be2fcdb7af1bd42752e169
exposed:              True
exposed-modules:      Test.Tasty.Ingredients.Rerun
import-dirs:          /usr/lib/ghc-9.4.8/site-local/tasty-rerun-1.1.20
library-dirs:         /usr/lib/ghc-9.4.8/site-local/tasty-rerun-1.1.20
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/tasty-rerun-1.1.20
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-tasty-rerun
hs-libraries:         HStasty-rerun-1.1.20-6YydCfWwoW7Ar9wECloK69
depends:
    base-4.17.2.1 containers-0.6.7 filepath-1.4.2.2 mtl-2.2.2
    optparse-applicative-0.18.1.0-5pRc89gLzX8JqTyOujyDZt
    split-0.2.5-Dujwwofvw7aEFmjRmWhj9Q stm-2.5.1.0
    tagged-0.8.9-KMS3sfDasKWItFZcxfaN6C
    tasty-1.5-KfqPODqIxWIB9zLnFruxu2 transformers-0.5.6.2

haddock-interfaces:   /usr/share/doc/haskell-tasty-rerun/html/tasty-rerun.haddock
haddock-html:         /usr/share/doc/haskell-tasty-rerun/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
